@@ -1,6 +1,6 @@
 ;;; mixal-mode.el --- Major mode for the mix asm language.
 
-;; Copyright (C) 2003 Free Software Foundation
+;; Copyright (C) 2003, 2005 Free Software Foundation
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -14,8 +14,8 @@
 
 ;; You should have received a copy of the GNU General Public
 ;; License along with this program; if not, write to the Free
-;; Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-;; MA 02111-1307 USA
+;; Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+;; MA 02110-1301 USA
 
 ;; Author: Pieter E.J. Pareit <pieter.pareit@skynet.be>
 ;; Maintainer: Pieter E.J. Pareit <pieter.pareit@skynet.be>
@@ -45,6 +45,10 @@
 ;; Have fun.
 
 ;;; History:
+;; Version 0.2:
+;; 06/04/05: mixasm no longer needs -g option
+;;           fontlocking of comments works in all? cases now
+;;           added some more mixal-operation-codes
 ;; Version 0.1:
 ;; Version 0.1.1:
 ;; 22/11/02: bugfix in fontlocking, needed to add a '-' to the regex.
@@ -69,8 +73,8 @@
 ;;; Syntax table
 (defvar mixal-mode-syntax-table
   (let ((st (make-syntax-table)))
-    (modify-syntax-entry ?* "<" st)
-    (modify-syntax-entry ?\n ">" st)
+    ; (modify-syntax-entry ?* "<" st)    we need to do a bit more to make
+    ; (modify-syntax-entry ?\n ">" st)    fontlocking for comments work
     st)
   "Syntax table for `dot-mode'.")
 
@@ -95,6 +99,7 @@ value.")
     "LD4" "LD5" "LD6" "LDX" "LDAN" "LD1N" "LD2N" "LD3N" "LD4N" "LD5N" "LD6N"
     "LDXN" "STA" "ST1" "ST2" "ST3" "ST4" "ST5" "ST6" "STX" "STJ" "STZ" "JBUS"
     "IOC" "IN" "OUT" "JRAD" "JMP" "JSJ" "JOV" "JNOV"
+    "JL" "JE" "JG" "JGE" "JNE" "JLE"
     "JAN" "J1N" "J2N" "J3N" "J4N" "J5N" "J6N" "JXN"
     "JAZ" "J1Z" "J2Z" "J3Z" "J4Z" "J5Z" "J6Z" "JXZ"
     "JAP" "J1P" "J2P" "J3P" "J4P" "J5P" "J6P" "JXP"
@@ -122,8 +127,11 @@ value.")
     (,(regexp-opt
        mixal-assembly-pseudoinstructions 'words)
      . mixal-font-lock-assembly-pseudoinstruction-face)
-    ("^[A-Z0-9a-z]*[ \t]+[A-Z0-9a-z]+[ \t]+[\\-A-Z0-9a-z,():]*[\t]+\\(.*\\)$"
-     (1 font-lock-comment-face)))
+    ("^[A-Z0-9a-z]*[ \t]+[A-ZO-9a-z]+[ \t]+\\(=.*=\\).*$"
+     (1 font-lock-constant-face))
+    ("^[A-Z0-9a-z]*[ \t]+[A-Z0-9a-z]+[ \t]+[A-Z0-9a-z,():+-\\*=\" ]*[\t]+\\(.*\\)$"
+     (1 font-lock-comment-face))
+    ("^\\*.*$" . font-lock-comment-face))
   "Keyword highlighting specification for `mixal-mode'.")
 ; (makunbound 'mixal-font-lock-keywords)
 
@@ -1300,7 +1308,7 @@ The converted character representation is stored in rAX."
   (set (make-local-variable 'font-lock-defaults) '(mixal-font-lock-keywords))
 ; might add an indent function in the future
 ;  (set (make-local-variable 'indent-line-function) 'mixal-indent-line)
-  (set (make-local-variable 'compile-command) (concat "mixasm -g "
+  (set (make-local-variable 'compile-command) (concat "mixasm "
 						      buffer-file-name))
   ;; mixasm will do strange when there is no final newline,
   ;; let emacs ensure that it is always there
