@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- xmixguile_cmd_dispatcher.c :
  * Implementation of the functions declared in xmixguile_cmd_dispatcher.h
  * ------------------------------------------------------------------
- * $Id: xmixguile_cmd_dispatcher.c,v 1.12 2004/06/23 10:47:27 jao Exp $
+ * $Id: xmixguile_cmd_dispatcher.c,v 1.14 2005/09/20 19:50:26 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -63,7 +63,7 @@ static SCM
 mixvm_cmd_ (SCM cmd, SCM arg)
 {
   char *com = NULL, *argu = NULL;
-  int len;
+  unsigned int len;
   gboolean result;
 
   SCM_ASSERT (SCM_STRINGP (cmd) || SCM_SYMBOLP (cmd),
@@ -115,7 +115,7 @@ static SCM
 mix_reg_ (SCM reg)
 {
   char *regis;
-  int len;
+  unsigned int len;
   long val = MIX_WORD_MAX + 1;
 
   SCM_ASSERT (SCM_STRINGP (reg) || SCM_SYMBOLP (reg), reg, SCM_ARG1, "mix-reg");
@@ -153,7 +153,7 @@ static SCM
 mix_set_reg_ (SCM reg, SCM value)
 {
   char *regis;
-  int len;
+  unsigned int len;
   long val;
   gboolean result = TRUE;
 
@@ -257,7 +257,7 @@ static SCM
 mix_set_cmp_ (SCM value)
 {
   gchar *val = NULL;
-  int len;
+  unsigned int len;
   mix_cmpflag_t result = -1;
 
   SCM_ASSERT (SCM_STRINGP (value) || SCM_SYMBOLP (value), value, SCM_ARG1,
@@ -458,7 +458,7 @@ mix_add_hook_ (SCM cmd, SCM function, gboolean pre)
 {
   gchar *cmdstr = NULL;
   mix_vm_command_t command;
-  int len;
+  unsigned int len;
   const gchar *fun = pre? "mix-add-pre-hook" : "mix-add-post-hook";
 
   SCM_ASSERT (SCM_STRINGP (cmd) || SCM_SYMBOLP (cmd), cmd, SCM_ARG1, fun);
